@@ -1,6 +1,6 @@
 from pygments.lexer import RegexLexer, DelegatingLexer, bygroups
 from pygments.lexers import RubyLexer
-from pygments.token import Text, Other
+from pygments.token import Text, Other, Keyword
 
 class PryPrefixLexer(RegexLexer):
     """
@@ -9,10 +9,16 @@ class PryPrefixLexer(RegexLexer):
     """
     tokens = {
         'root' : [
+          # Headings from various pry commands
+          (r'^[A-Z][a-z ]+(:\n| .*\n)', bygroups(Keyword, Text)),
+          # line-numbered code listings
+          (r'^( *(?:=> *)?)(\d+)(: )(.*\n)', bygroups(Text, Number, Text, Other)),
           # Match the default prompt: [1] pry(main)>
           # the continuation prompt:  [1] pry(main)*
           # and output hash-rocket:   =>
-          (r'(.*?(?:\)>|=>|\)\*) )(.*\n)', bygroups(Text, Other))
+          (r'(.*?(?:\)>|=>|\)\*) )(.*\n)', bygroups(Text, Other)),
+          # trailing prompt
+          (r'(.*?(?:\)>|=>|\)\*)\n)', bygroups(Text)),
         ]
     }
 
